@@ -28,25 +28,23 @@ class NestedType(AbstractType):
     """
     Class custom handle nested schema
     """
-    schema = None
-    data_handling_function = None
-
-    def __init__(self, schema, data_handling_function=None, *args, **kwargs):
+    def __init__(self, schema, data_handling_function, *args, **kwargs):
         super(NestedType, self).__init__(*args, **kwargs)
+
         self.schema = schema
         self.data_handling_function = data_handling_function
 
-    def data_handle(self, data):
-        if self.data_handling_function:
-            return self.data_handling_function(data)
+        self._check_args()
 
-        return data
+    def _check_args(self):
+        if not self.schema:
+            raise ValueError("Incorrect schema!")
 
-    def _serialize(self, tag):
-        return serialize_by_inner_schema(self.schema, tag)
+        if not callable(self.data_handling_function):
+            raise TypeError(f"{self.data_handling_function} is not callable!")
 
     def convert_method(self, tag):
-        data = self._serialize(tag)
-        response = self.data_handle(data)
+        data = serialize_by_inner_schema(self.schema, tag)
+        response = self.data_handling_function(data)
 
         return response
